package com.nisum.splitmerchantpayment.controllers;

import com.nisum.splitmerchantpayment.entity.OrderDao;
import com.nisum.splitmerchantpayment.entity.Product;
import com.nisum.splitmerchantpayment.model.ProductDto;
import com.nisum.splitmerchantpayment.service.AdminService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * Admin controller class where we give all
 * our rest API's and various endpoints
 */
@RestController
public class AdminController {
    @Autowired
    private AdminService adminService;

    /**
     *  This method is used to give endpoint to save the product
     *  details given using post mapping.
     * @param productDto
     * @return String with response message
     */
    @PostMapping(value = "/products")
    public ResponseEntity<String> save(@RequestBody ProductDto productDto) {
        Product product = adminService.addProduct(productDto);
        return product != null ? ResponseEntity.status(HttpStatus.OK).body("product is saved") :
                ResponseEntity.status(HttpStatus.BAD_REQUEST).body("unable to save product");
    }

    /**
     * This method is to get the product of particular id
     * with endpoint of rest product with id using get mapping
     * @param id
     * @return Product response request
     */
    @GetMapping(value = "/products/{id}")
    public ResponseEntity<Product> getById(@PathVariable(name = "id") String id) {
        Product product = adminService.getProductById(id);
        return product != null ? ResponseEntity.status(HttpStatus.OK).body(product) :
                ResponseEntity.status(HttpStatus.BAD_REQUEST).body(product);
    }

    /**
     * This method is used to get all products available or which
     * present in the data base by using the endpoint get mapping of products
     * @return Products with iterating all its fields
     */
    @GetMapping("/products")
    public ResponseEntity<Iterable<Product>> getAllProducts() {
        Iterable<Product> product = adminService.getAllProducts();
        return new ResponseEntity<>(product, HttpStatus.OK);
    }

    /**
     * This method is used to give the rest endpoint of the products which
     * perform soft-delete operation of particular given id using delete mapping
     * @param id
     */
    @DeleteMapping("/products/{id}")
    public ResponseEntity<String> softDeleteProduct(@PathVariable String id) {
        adminService.deleteProductById(id);
        return new ResponseEntity<String>("product deleted",HttpStatus.OK);
    }

    /**
     * This method is used to give the list of orders using the endpoint of
     * get mapping to all orders of every customer.
     * @return orders of list
     */
    @GetMapping("/allOrders")
    public ResponseEntity<List<OrderDao>> getAllOrders() {
        List<OrderDao> orderDaoList = adminService.getAllOrders();
        return new ResponseEntity<>(orderDaoList, HttpStatus.OK);
    }

    /**
     * This method is used to give the response of the endpoint by using put-mapping
     * to update a particular product
     * @param id
     * @param productDto
     * @return
     */
    @PutMapping("/products/{id}")
    public ResponseEntity<String> updateProduct(@PathVariable String id,@RequestBody ProductDto productDto) {
        Product product= adminService.updateProductById(id, productDto);
        return product != null ? ResponseEntity.status(HttpStatus.OK).body("product is Updated") :
                ResponseEntity.status(HttpStatus.NOT_ACCEPTABLE).body("unable to update the product");
    }
}
