package com.nisum.splitmerchantpayment.entity;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.SQLDelete;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
@Entity
@Table(name = "product")
@SQLDelete(sql = "update Product set is_active = false where product_id=? and is_active = true")
/**
 * This is Product class which has all setters and getters constructors
 * toString methods by single lombok annotation
 */
public class Product {
    @Id
    @Column(name = "product_id")
    private String productId;

    @OneToOne(targetEntity = ProductName.class, cascade = CascadeType.DETACH)
    @JoinColumn(name = "product_name_id")
    @NotNull
    private ProductName productName;

    @OneToOne(targetEntity = Brand.class, cascade = CascadeType.DETACH)
    @JoinColumn(name = "brand_id")
    @NotNull
    private Brand brand;

    @OneToOne(targetEntity = Category.class, cascade = CascadeType.DETACH)
    @JoinColumn(name = "category_id")
    @NotNull
    private Category category;

    @Column(name = "ideal_for")
    @NotNull
    private String idealFor;

    @Column(name = "price")
    @NotNull
    private Double price;

    @Column(name = "is_active", nullable = false, columnDefinition = "boolean default TRUE")
    @NotNull
    private Boolean isActive;

    @Column(name = "size")
    @Embedded
    @NotNull
    private Size size;

    @Column(name = "vendor_account")
    @NotNull
    private String vendorAccount;

    @Column(name = "platform_charge")
    @NotNull
    private Double platformCharge;
}
